**Example 1: 导出备份详情列表**

根据过滤参数导出备份详情列表

Input: 

```
tccli cwp ExportRansomDefenseMachineList --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "requestId",
        "TaskId": "123213"
    }
}
```

